@@ -266,7 +266,7 @@ gda_data_model_dir_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaDataModelDirClass),
 			(GBaseInitFunc) NULL,
@@ -285,12 +285,12 @@ gda_data_model_dir_get_type (void)
                         NULL
                 };
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaDataModelDir", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -688,7 +688,7 @@ gda_data_model_dir_new (const gchar *basedir)
  *
  * Get the list of errors which have occurred while using @model
  *
- * Returns: (transfer none) (element-type GObject.Error) : a read-only list of #GError pointers, or %NULL if no error has occurred
+ * Returns: (transfer none) (element-type GLib.Error) : a read-only list of #GError pointers, or %NULL if no error has occurred
  */
 const GSList *
 gda_data_model_dir_get_errors (GdaDataModelDir *model)
