@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2007 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -152,6 +153,27 @@ prov_test_check_types_schema (GdaConnection *cnc)
 	GdaDataModel *schema_m;
 	GError *error = NULL;
 	gchar *str;
+	GdaMetaContext mcontext = {"_builtin_data_types", 0, NULL, NULL};
+	g_print ("updating [%s]\n", mcontext.table_name);
+	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
+		g_warning ("Can't update meta store: %s\n",
+			   error && error->message ? error->message : "???");
+		return FALSE;
+	}
+	mcontext.table_name="_udt";
+	g_print ("updating [%s]\n", mcontext.table_name);
+	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
+		g_warning ("Can't update meta store: %s\n",
+			   error && error->message ? error->message : "???");
+		return FALSE;
+	}
+	mcontext.table_name="_domains";
+	g_print ("updating [%s]\n", mcontext.table_name);
+	if (! gda_connection_update_meta_store (cnc, &mcontext, &error)) {
+		g_warning ("Can't update meta store: %s\n",
+			   error && error->message ? error->message : "???");
+		return FALSE;
+	}
 	
 	schema_m = gda_connection_get_meta_store_data (cnc, GDA_CONNECTION_META_TYPES, &error, 0);
 	if (!schema_m) {
@@ -286,7 +308,7 @@ iter_is_correct (GdaDataModelIter *iter, GdaDataModel *ref_model)
         g_object_get (G_OBJECT (iter), "current-row", &rownum, NULL);
 
         cols = gda_data_model_get_n_columns (ref_model);
-        if (cols != g_slist_length (GDA_SET (iter)->holders)) {
+        if (cols != (gint)g_slist_length (GDA_SET (iter)->holders)) {
 #ifdef CHECK_EXTRA_INFO
                 g_warning ("Number of columns in iter is not the same as for the referenced data model\n");
 #endif
